==> jetjob_1.6.0.0.tar.gz: jetjob_1.6.0.0/htdocs/memo_main.php <==
<?php
//==============================================================
// Program Name		: address1
// File Name		: memo_main.php
//--------------------------------------------------------------
// Date             : 2000/07/28
// Author           : M Iura
//--------------------------------------------------------------
// Note				: ⡦ǽ
//                  : 
//--------------------------------------------------------------
// Rev.             : 2001/05/09 ơ֥̾ѹ
//                  : 
//==============================================================

require("jetjob.inc");				// 

//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================
	print("<html>\n");
	print("<head>\n");
	print("<META http-equiv=\"Content-Language\" content=\"ja\">\n");
	printf("<META http-equiv=\"Content-Type\" content=\"text/html;charset=%s\">\n", $JJ_OUTPUT_CHARSET);
	printf("<LINK REL=\"STYLESHEET\" TYPE=\"text/css\" HREF=\"%s\">\n", $JJ_CSS_ROOT . $JJ_CSS_NAME);
	print("</head>\n");
	print("<frameset cols=\"190,*\">\n");
	printf("<frame src=\"memo_folder.php?sel=%s\" name=\"submenu\">\n", $sel);
	if(!isset($gp))	$gp="";
	if(!isset($atesaki1))	$atesaki1="";
	if(!isset($mem_ikisaki))	$mem_ikisaki="";
	printf("<frame src=\"memo_index.php?mode=%s&sel_id=%s&gp=%s&atesaki1=%s&mem_ikisaki=%s\" name=\"content\">\n", 
							$mode, $sel_id, $gp, $atesaki1, $mem_ikisaki);
	print("</frameset>\n");
	print("</html>\n");

?>

==> jetjob_1.6.0.3.tar.gz: jetjob_1.6.0.3/htdocs/memo_main.php <==
<?php
//==============================================================
// Program Name		: address1
// File Name		: memo_main.php
//--------------------------------------------------------------
// Date             : 2000/07/28
// Author           : M Iura
//--------------------------------------------------------------
// Note				: ⡦ǽ
//                  : 
//--------------------------------------------------------------
// Rev.             : 2001/05/09 ơ֥̾ѹ
//                  : 
//==============================================================

require("jetjob.inc.php");

//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================
	print("<html>\n");
	print("<head>\n");
	print("<META http-equiv=\"Content-Language\" content=\"ja\">\n");
	printf("<META http-equiv=\"Content-Type\" content=\"text/html;charset=%s\">\n", $JJ_OUTPUT_CHARSET);
	printf("<LINK REL=\"STYLESHEET\" TYPE=\"text/css\" HREF=\"%s\">\n", $JJ_CSS_ROOT . $JJ_CSS_NAME);
	print("</head>\n");
	print("<frameset cols=\"190,*\">\n");
	printf("<frame src=\"memo_folder.php?sel=%s\" name=\"submenu\">\n", $sel);
	if(!isset($gp))	$gp="";
	if(!isset($atesaki1))	$atesaki1="";
	if(!isset($mem_ikisaki))	$mem_ikisaki="";
	printf("<frame src=\"memo_index.php?mode=%s&sel_id=%s&gp=%s&atesaki1=%s&mem_ikisaki=%s\" name=\"content\">\n", 
							$mode, $sel_id, $gp, $atesaki1, $mem_ikisaki);
	print("</frameset>\n");
	print("</html>\n");

?>
